@@ -3,9 +3,14 @@ def toNum(inp):
     '〇': 0, '一': 1, '二': 2, '三': 3, '四': 4, '五': 5, '六': 6, '七': 7, '八': 8, '九': 9, '零': 0,
     '壹': 1, '貳': 2, '叁': 3, '肆': 4, '伍': 5, '陸': 6, '柒': 7, '捌': 8, '玖': 9, '貮': 2, '兩': 2}
     unit_d = {'零':'0','十':'s0','百':'s00','千':'s000','萬':'s0000','億':'s00000000','万':'s0000', '亿':'s00000000'}
-    result_list = []
-    unit = ['十', '百', '千', '萬', '億'] 
     unit_zh = {'十':'十','百':'百','千':'千','萬':'萬','億':'億','万':'萬', '亿':'億'}
+    unit = ['十', '百', '千', '萬', '億'] 
+    result_list = []
+    unit_list = unit[0:3]
+    for i in unit[3:]:
+        unit_list.append(i)
+        for j in unit_list[:-1]:
+            unit_list.append(j+i)
     if(all([i not in inp for i in unit])):
         rs = ""
         for i in inp:
@@ -17,7 +22,7 @@ def toNum(inp):
         if i in list(unit_zh.keys()):
             i = unit_zh[inp[index]]
             inp = inp[0:index] + i +inp[index+1:]
-            if(inp[index-1] in unit[1:] and index != len(inp) - 1):
+            if(inp[index-1] in unit[1:] and index != len(inp) - 1 and all([inp[index-len(u)+1:index+1] != u for u in unit_list if index >= len(u)-1 and len(u) > 1])):
                 inp = inp[0:index]+'一'+inp[index:]
             elif(index == 0):
                 inp = '一' + inp
@@ -73,4 +78,4 @@ def toNum(inp):
     return sumNum(sumNum(sumNum(result_list),['s00000000']),[])[0]
 
 if __name__ == "__main__":
-    print(toNum('十万亿'))
\ No newline at end of file
+    print(toNum('十億億'))
\ No newline at end of file
